﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
//using System.Threading.Tasks;
using System.Windows.Forms;
using Phidget22;
using Phidget22.Events;
using Phidget22.ExampleUtils;

namespace LightSensor_Example {
	public partial class Form1 : Form {
		CommandLineOpen open;
		LightSensor lux = null;
		private ErrorEventBox errorBox;
		private DataGraphBox luxGraphBox;
		formCleaner cleaner;

		public Form1() {
			open = new CommandLineOpen(this);
			cleaner = new formCleaner(this);
			InitializeComponent();
		}

		public Form1(String[] commandLine) {
			open = new CommandLineOpen(this);
			cleaner = new formCleaner(this);
			open.commandLine = commandLine;
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e) {
			this.Size = this.MinimumSize;


			errorBox = new ErrorEventBox(this);
			luxGraphBox = new DataGraphBox(this, "Lux");
			lux = new LightSensor();

			this.Size = this.MinimumSize;

			lux.Attach += lux_attach;
			lux.Detach += lux_detach;
			lux.Error += lux_error;
			lux.IlluminanceChange += lux_change;

			commandLineData phidgetParameters = open.parseCmdLine(); //get command line parameters

			try { //set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.cs, you can check there to see them.
				lux.Channel = phidgetParameters.Channel; //selects the channel on the device to open
				lux.DeviceSerialNumber = phidgetParameters.SerialNumber; //selects the device or hub to open
				lux.HubPort = phidgetParameters.HubPort; //selects the port on the hub to open
				lux.IsHubPortDevice = phidgetParameters.isHubPortDevice; //is the device a port on a VINT hub?

				if (phidgetParameters.isRemote) //are we trying to open a remote device?
				{
					lux.IsRemote = true;
					Net.EnableServerDiscovery(ServerType.Device); //turn on network scan
					if (phidgetParameters.Password != null && phidgetParameters.ServerName != null)
						Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password); //set the password if there is one
				} else
					lux.IsLocal = true;

				lux.Open(); //open the device specified by the above parameters
			} catch (PhidgetException ex) { errorBox.addMessage("Error opening device: " + ex.Message); }
		}
		private void Form1_FormClosing(object sender, FormClosingEventArgs e) {
			lux.Close();
		}

		void lux_attach(object sender, Phidget22.Events.AttachEventArgs e) {
			phidgetInfoBox1.FillPhidgetInfo((Phidget)sender);

			LightSensor attachedDevice = (LightSensor)sender;

			try {
				dataIntervalTrk.Unit = "ms";
				dataIntervalTrk.initializeRange(attachedDevice.MinDataInterval, attachedDevice.MaxDataInterval);
				dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString();
				dataIntervalTrk.Minimum = attachedDevice.MinDataInterval;
				dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString();
				dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval;
				dataIntervalTrk.Value = attachedDevice.DataInterval;
				dataIntervalTrk.trkText = attachedDevice.DataInterval.ToString();

				changeTriggerTrk.Unit = "lx";
				changeTriggerTrk.minTxt = attachedDevice.MinIlluminanceChangeTrigger.ToString();
				changeTriggerTrk.Minimum = attachedDevice.MinIlluminanceChangeTrigger;
				changeTriggerTrk.Maximum = attachedDevice.MaxIlluminanceChangeTrigger;
				changeTriggerTrk.maxTxt = attachedDevice.MaxIlluminanceChangeTrigger.ToString();
				changeTriggerTrk.trkText = attachedDevice.IlluminanceChangeTrigger.ToString();
				changeTriggerTrk.Value = attachedDevice.IlluminanceChangeTrigger;
			} catch (PhidgetException ex) { errorBox.addMessage("Error initializing device: " + ex.Message); }

			settingsBox.Visible = true;
			outputBox.Visible = true;

		}
		void lux_detach(object sender, Phidget22.Events.DetachEventArgs e) {
			phidgetInfoBox1.Clear();
			cleaner.clean();

			settingsBox.Visible = false;
			outputBox.Visible = false;
		}
		void lux_error(object sender, Phidget22.Events.ErrorEventArgs e) {
			errorBox.addMessage(e.Description);

			if (e.Code == ErrorEventCode.Saturation)
				luxGraphBox.addGap();
		}

		void lux_change(object sender, Phidget22.Events.LightSensorIlluminanceChangeEventArgs e) {
			try {
				luxvalue.Text = e.Illuminance.ToString() + " lx";
				luxGraphBox.addData(e.Illuminance, lux.DataInterval);
			} catch (PhidgetException ex) { errorBox.addMessage("Error reading illuminance: " + ex.Message); }
		}


		private void dataIntervalTrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					lux.DataInterval = (int)dataIntervalTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting data interval: " + ex.Message);
				}
			}
		}

		private void dataIntervalTrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				lux.DataInterval = (int)dataIntervalTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting data interval: " + ex.Message);
			}
		}

		private void changeTriggertrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					lux.IlluminanceChangeTrigger = changeTriggerTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting change trigger: " + ex.Message);
				}
			}
		}

		private void changeTriggertrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				lux.IlluminanceChangeTrigger = changeTriggerTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting change trigger: " + ex.Message);
			}
		}

		private void luxGraphButton_Click(object sender, EventArgs e) {
			if (!luxGraphBox.Visible)
				luxGraphBox.Show();
		}

		private void dataIntervalTrk_SetClick(object sender, EventArgs e) {
			try {
				lux.DataInterval = (int)dataIntervalTrk.Value;
			} catch (Exception ex) { errorBox.addMessage("Error setting change trigger: " + ex.Message); }
		}

		private void dataIntervalTrk_SetEnter(object sender, KeyEventArgs e) {
			if (e.KeyCode == Keys.Enter) {
				try {
					lux.DataInterval = (int)dataIntervalTrk.Value;
				} catch (Exception ex) { errorBox.addMessage("Error setting change trigger: " + ex.Message); }
			}
		}

		private void changeTriggerTrk_SetClick(object sender, EventArgs e) {
			try {
				lux.IlluminanceChangeTrigger = changeTriggerTrk.Value;
			} catch (Exception ex) { errorBox.addMessage("Error setting change trigger: " + ex.Message); }
		}

		private void changeTriggerTrk_SetEnter(object sender, KeyEventArgs e) {
			if (e.KeyCode == Keys.Enter) {
				try {
					lux.IlluminanceChangeTrigger = changeTriggerTrk.Value;
				} catch (Exception ex) { errorBox.addMessage("Error setting change trigger: " + ex.Message); }
			}
		}
	}
}
